# Population Synthesis Toolkit (PST)

PST is a very flexible tool that allows users to perform stellar population synthesis using a variety of SSP models, as well as computing observables quantities such as spectra, photometry or equivalent widths from both synthetic and observational data.

## Status
[![Documentation Status](https://readthedocs.org/projects/population-synthesis-toolkit/badge/?version=latest)](https://population-synthesis-toolkit.readthedocs.io/en/latest/?badge=latest)
![Unit tests](https://github.com/paranoya/population-synthesis-toolkit/actions/workflows/testing.yml/badge.svg)
[![DOI](https://joss.theoj.org/papers/10.21105/joss.08203/status.svg)](https://doi.org/10.21105/joss.08203)

## Documentation

Check the [documentation page](https://population-synthesis-toolkit.readthedocs.io/en/latest/) for extensive information.

## Installation

Follow the instructions at the [installation section](https://population-synthesis-toolkit.readthedocs.io/en/latest/installation.html) in the documentation page for details on installing PST.

## Tutorials

The [tutorials](./tutorials) illustrate the basic functionality of PST through simple example use cases.

## Contributing

If you want to contribute to the project, feel free to report any [issues](https://github.com/paranoya/population-synthesis-toolkit/issues) you may find and/or fork this repository and open a pull request.
